@@ -8,7 +8,6 @@ use JSON::PP;
 
 # ABSTRACT: Module to ask for the balance for the Nexmo SMS API!
 
-
 our $VERSION = '0.02';
 
 my %attrs = (
@@ -28,6 +27,40 @@ for my $attr ( keys %attrs ) {
     };
 }
 
+=head1 SYNOPSIS
+
+This module simplifies sending SMS through the Nexmo API.
+
+
+    use Nexmo::SMS::GetBalance;
+
+    my $nexmo = Nexmo::SMS::GetBalance->new(
+        server   => 'http://rest.nexmo.com/sms/json',
+        username => 'testuser1',
+        password => 'testpasswd2',
+    );
+        
+    my $balance = $sms->get_balance;
+
+=head1 METHODS
+
+=head2 new
+
+create a new object
+
+    my $object = Nexmo::SMS::GetBalance->new(
+        server   => 'http://rest.nexmo.com/sms/json',
+        username => 'testuser1',
+        password => 'testpasswd2',
+    );
+
+This method recognises these parameters:
+
+    server            => 'required',
+    username          => 'required',
+    password          => 'required',
+
+=cut
 
 sub new {
     my ($class,%param) = @_;
@@ -49,6 +82,16 @@ sub new {
     return $self;
 }
 
+=head2 user_agent
+
+Getter/setter for the user_agent attribute of the object. By default a new
+object of LWP::UserAgent is used, but you can use your own class as long as it
+is compatible to LWP::UserAgent.
+
+  $sms->user_agent( MyUserAgent->new );
+  my $ua = $sms->user_agent;
+
+=cut
 
 sub user_agent {
     my ($self,$ua) = @_;
@@ -57,12 +100,17 @@ sub user_agent {
     return $self->{__ua__};
 }
 
+=head2 get_balance
+
+This actually calls the Nexmo SMS API. It returns the balance of the account.
+
+   my $balance = $object->get_balance;
+
+=cut
 
 sub get_balance {
     my ($self) = shift;
     
-    use Data::Dumper;
-    
     my $url = sprintf "%saccount/get-balance/%s/%s",
         $self->server,
         $self->username,
@@ -87,72 +135,6 @@ sub get_balance {
     return $perl->{'value'};
 }
 
-
-1;
-
-
-__END__
-=pod
-
-=head1 NAME
-
-Nexmo::SMS::GetBalance - Module to ask for the balance for the Nexmo SMS API!
-
-=head1 VERSION
-
-version 0.06
-
-=head1 SYNOPSIS
-
-This module simplifies sending SMS through the Nexmo API.
-
-    use Nexmo::SMS::GetBalance;
-
-    my $nexmo = Nexmo::SMS::GetBalance->new(
-        server   => 'http://rest.nexmo.com/sms/json',
-        username => 'testuser1',
-        password => 'testpasswd2',
-    );
-        
-    my $balance = $sms->get_balance;
-
-=head1 VERSION
-
-Version 0.02
-
-=head1 METHODS
-
-=head2 new
-
-create a new object
-
-    my $object = Nexmo::SMS::GetBalance->new(
-        server   => 'http://rest.nexmo.com/sms/json',
-        username => 'testuser1',
-        password => 'testpasswd2',
-    );
-
-This method recognises these parameters:
-
-    server            => 'required',
-    username          => 'required',
-    password          => 'required',
-
-=head2 user_agent
-
-Getter/setter for the user_agent attribute of the object. By default a new
-object of LWP::UserAgent is used, but you can use your own class as long as it
-is compatible to LWP::UserAgent.
-
-  $sms->user_agent( MyUserAgent->new );
-  my $ua = $sms->user_agent;
-
-=head2 get_balance
-
-This actually calls the Nexmo SMS API. It returns the balance of the account.
-
-   my $balance = $object->get_balance;
-
 =head1 Attributes
 
 These attributes are available for C<Nexmo::SMS::GetBalance> objects. For each
@@ -171,25 +153,7 @@ attribute there is a getter/setter:
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2011 Renee Baecker.
-
-This program is released under the following license: artistic_2
-
-=head1 AUTHOR
-
-Renee Baecker <module@renee-baecker.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2011 by Renee Baecker.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
 =cut
 
+1;
+
