@@ -10,7 +10,6 @@ use JSON::PP;
 
 # ABSTRACT: Module that respresents a text message for the Nexmo SMS API!
 
-
 our $VERSION = '0.02';
 
 my %attrs = (
@@ -37,6 +36,54 @@ for my $attr ( keys %attrs ) {
     };
 }
 
+=head1 SYNOPSIS
+
+This module simplifies sending SMS through the Nexmo API.
+
+
+    use Nexmo::SMS::TextMessage;
+
+    my $nexmo = Nexmo::SMS::TextMessage->new(
+        server   => 'http://rest.nexmo.com/sms/json',
+        username => 'testuser1',
+        password => 'testpasswd2',
+        text     => 'This is a test',
+        from     => 'Test02',
+        to       => '452312432',
+    );
+        
+    my $response = $sms->send || die $sms->errstr;
+    
+    if ( $response->is_success ) {
+        print "SMS was sent...\n";
+    }
+
+=head1 METHODS
+
+=head2 new
+
+create a new object
+
+    my $message = Nexmo::SMS::TextMessage->new(
+        server   => 'http://rest.nexmo.com/sms/json',
+        username => 'testuser1',
+        password => 'testpasswd2',
+    );
+
+This method recognises these parameters:
+
+    text              => 'required',
+    from              => 'required',
+    to                => 'required',
+    server            => 'required',
+    username          => 'required',
+    password          => 'required',
+    type              => 'optional',
+    status_report_req => 'optional',
+    client_ref        => 'optional',
+    network_code      => 'optional',
+
+=cut
 
 sub new {
     my ($class,%param) = @_;
@@ -58,6 +105,16 @@ sub new {
     return $self;
 }
 
+=head2 user_agent
+
+Getter/setter for the user_agent attribute of the object. By default a new
+object of LWP::UserAgent is used, but you can use your own class as long as it
+is compatible to LWP::UserAgent.
+
+  $sms->user_agent( MyUserAgent->new );
+  my $ua = $sms->user_agent;
+
+=cut
 
 sub user_agent {
     my ($self,$ua) = @_;
@@ -66,6 +123,13 @@ sub user_agent {
     return $self->{__ua__};
 }
 
+=head2 errstr
+
+return the "last" error as string.
+
+    print $sms->errstr;
+
+=cut
 
 sub errstr {
     my ($self,$message) = @_;
@@ -74,6 +138,15 @@ sub errstr {
     return $self->{__errstr__};
 }
 
+=head2 send
+
+This actually calls the Nexmo SMS API. It returns a L<Nexmo::SMS::Response> object or
+C<undef> (on failure).
+
+   my $sms = Nexmo::SMS::TextMessage->new( ... );
+   $sms->send or die $sms->errstr;
+
+=cut
 
 sub send {
     my ($self) = shift;
@@ -112,6 +185,16 @@ sub send {
     return $response_object;
 }
 
+=head2 check_needed_params
+
+This method checks if all needed parameters are passed.
+
+  my $params_not_ok = Nexmo::SMS::TextMessage->check_needed_params( ... );
+  if ( $params_not_ok ) {
+      print "Please check $params_not_ok";
+  }
+
+=cut
 
 sub check_needed_params {
     my ($class,%params) = @_;
@@ -127,103 +210,6 @@ sub check_needed_params {
     return join ", ", @params_not_ok;
 }
 
-
-1;
-
-
-__END__
-=pod
-
-=head1 NAME
-
-Nexmo::SMS::TextMessage - Module that respresents a text message for the Nexmo SMS API!
-
-=head1 VERSION
-
-version 0.06
-
-=head1 SYNOPSIS
-
-This module simplifies sending SMS through the Nexmo API.
-
-    use Nexmo::SMS::TextMessage;
-
-    my $nexmo = Nexmo::SMS::TextMessage->new(
-        server   => 'http://rest.nexmo.com/sms/json',
-        username => 'testuser1',
-        password => 'testpasswd2',
-        text     => 'This is a test',
-        from     => 'Test02',
-        to       => '452312432',
-    );
-        
-    my $response = $sms->send || die $sms->errstr;
-    
-    if ( $response->is_success ) {
-        print "SMS was sent...\n";
-    }
-
-=head1 VERSION
-
-Version 0.02
-
-=head1 METHODS
-
-=head2 new
-
-create a new object
-
-    my $message = Nexmo::SMS::TextMessage->new(
-        server   => 'http://rest.nexmo.com/sms/json',
-        username => 'testuser1',
-        password => 'testpasswd2',
-    );
-
-This method recognises these parameters:
-
-    text              => 'required',
-    from              => 'required',
-    to                => 'required',
-    server            => 'required',
-    username          => 'required',
-    password          => 'required',
-    type              => 'optional',
-    status_report_req => 'optional',
-    client_ref        => 'optional',
-    network_code      => 'optional',
-
-=head2 user_agent
-
-Getter/setter for the user_agent attribute of the object. By default a new
-object of LWP::UserAgent is used, but you can use your own class as long as it
-is compatible to LWP::UserAgent.
-
-  $sms->user_agent( MyUserAgent->new );
-  my $ua = $sms->user_agent;
-
-=head2 errstr
-
-return the "last" error as string.
-
-    print $sms->errstr;
-
-=head2 send
-
-This actually calls the Nexmo SMS API. It returns a L<Nexmo::SMS::Response> object or
-C<undef> (on failure).
-
-   my $sms = Nexmo::SMS::TextMessage->new( ... );
-   $sms->send or die $sms->errstr;
-
-=head2 check_needed_params
-
-This method checks if all needed parameters are passed.
-
-  my $params_not_ok = Nexmo::SMS::TextMessage->check_needed_params( ... );
-  if ( $params_not_ok ) {
-      print "Please check $params_not_ok";
-  }
-
 =head1 Attributes
 
 These attributes are available for C<Nexmo::SMS::TextMessage> objects:
@@ -252,25 +238,7 @@ These attributes are available for C<Nexmo::SMS::TextMessage> objects:
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2011 Renee Baecker.
-
-This program is released under the following license: artistic_2
-
-=head1 AUTHOR
-
-Renee Baecker <module@renee-baecker.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2011 by Renee Baecker.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
 =cut
 
+1;
+
